@@ -8,7 +8,6 @@ import calendar
 from datetime import date, datetime, timedelta, timezone
 from typing import Optional, Tuple, List, Union
 
-
 class TimeUtils:
     """时间工具类，提供各种时间相关的静态方法"""
 
@@ -94,6 +93,17 @@ class TimeUtils:
         last_month = today.month - 1 if today.month > 1 else 12
         return last_month
 
+    @staticmethod
+    def get_last_two_month() -> int:
+        """获取上上个月的月份"""
+        today = datetime.today()
+        # 计算上上个月：当前月份减2
+        last_two_month = today.month - 2
+        # 处理跨年情况
+        if last_two_month < 1:
+            last_two_month += 12
+        return last_two_month
+
     # ==================== 日期范围计算 ====================
 
     @staticmethod
@@ -285,6 +295,7 @@ class TimeUtils:
             current_date += timedelta(days=1)
 
         return date_list
+
     # ==================== 月份相关 ====================
 
     @staticmethod
@@ -299,6 +310,24 @@ class TimeUtils:
 
         return first_day.strftime("%Y-%m-%d"), last_day.strftime("%Y-%m-%d")
 
+    @staticmethod
+    def get_last_two_month_range() -> Tuple[str, str]:
+        """获取上上个月的第一天和最后一天"""
+        today = datetime.today()
+        # 计算上上个月
+        last_two_month = today.month - 2
+        year = today.year
+
+        # 处理跨年情况
+        if last_two_month < 1:
+            last_two_month += 12
+            year -= 1
+
+        first_day = datetime(year, last_two_month, 1)
+        last_day = datetime(year, last_two_month, calendar.monthrange(year, last_two_month)[1])
+
+        return first_day.strftime("%Y-%m-%d"), last_day.strftime("%Y-%m-%d")
+
     @staticmethod
     def get_last_month_range_time_str() -> Tuple[str, str]:
         """获取上个月第一天和最后一天的时间字符串"""
@@ -329,6 +358,17 @@ class TimeUtils:
 
         return start_timestamp, end_timestamp
 
+    @staticmethod
+    def get_year_range_time(year=2024):
+        """获取某一整年的第一天和最后一天的毫秒级时间戳"""
+        first_day = datetime(year, 1, 1, 0, 0, 0)
+        last_day = datetime(year, 12, 31, 0, 0, 0, 0)
+
+        start_timestamp = int(first_day.timestamp() * 1000)
+        end_timestamp = int(last_day.timestamp() * 1000)
+
+        return start_timestamp, end_timestamp
+
     @staticmethod
     def is_in_month(time_str: str, month: int, fmt: str = "%Y-%m-%d") -> bool:
         """
@@ -618,7 +658,6 @@ class TimeUtils:
 
         return mtime_dt.strftime('%Y-%m-%d %H:%M:%S') if to_str else mtime_dt
 
-
 # ==================== 便捷函数 ====================
 # 为了保持向后兼容，提供一些便捷函数
 
@@ -626,197 +665,158 @@ def get_current_date() -> str:
     """获取当前日期，格式为 YYYYMMDD"""
     return TimeUtils.get_current_date()
 
-
 def get_current_datetime() -> str:
     """获取当前日期时间，格式为 YYYYMMDDHHMMSS"""
     return TimeUtils.get_current_datetime()
 
-
 def current_datetime() -> str:
     """获取当前日期时间，格式为 YYYY-MM-DD HH:MM:SS"""
     return TimeUtils.current_datetime()
 
-
 def today_date() -> str:
     """获取今天的日期，格式为 YYYY-MM-DD"""
     return TimeUtils.today_date()
 
-
 def today_date_hour() -> str:
     """获取今天的日期和小时，格式为 YYYY-MM-DD_HH"""
     return TimeUtils.today_date_hour()
 
-
 def get_yesterday(dt: Optional[str] = None) -> str:
     """获取昨天的日期"""
     return TimeUtils.get_yesterday(dt)
 
-
 def tomorrow_date() -> str:
     """获取明天的日期"""
     return TimeUtils.tomorrow_date()
 
-
 def before_yesterday() -> str:
     """获取前天的日期"""
     return TimeUtils.before_yesterday()
 
-
 def get_current_year() -> int:
     """获取当前年份"""
     return TimeUtils.get_current_year()
 
-
 def get_current_month() -> int:
     """获取当前月份"""
     return TimeUtils.get_current_month()
 
-
 def get_last_month() -> int:
     """获取上个月的月份"""
     return TimeUtils.get_last_month()
 
-
 def get_week_num() -> int:
     """获取当前是第几周"""
     return TimeUtils.get_week_num()
 
-
 def get_period() -> str:
     """获取当前时间段（上午/下午/晚上）"""
     return TimeUtils.get_period()
 
-
 def get_period2() -> str:
     """获取当前时间段（AM/PM）"""
     return TimeUtils.get_period2()
 
-
 def get_chinese_weekday(date_str: str) -> str:
     """根据输入的日期字符串返回中文星期几"""
     return TimeUtils.get_chinese_weekday(date_str)
 
-
 def get_weekday_name(date_str: str) -> str:
     """获取中文星期名称（简短格式）"""
     return TimeUtils.get_weekday_name(date_str)
 
-
 def is_in_month(time_str: str, month: int, fmt: str = "%Y-%m-%d") -> bool:
     """判断时间字符串是否在指定月份"""
     return TimeUtils.is_in_month(time_str, month, fmt)
 
-
 def date_trans(d_t: str) -> str:
     """无斜杠日期转成有斜杠日期"""
     return TimeUtils.date_trans(d_t)
 
-
 def is_date_greater_or_equal(date_str: str) -> bool:
     """比较指定日期是否大于或等于今天的日期"""
     return TimeUtils.is_date_greater_or_equal(date_str)
 
-
 def is_yesterday(create_time_str: str, dt: Optional[str] = None) -> bool:
     """判断给定的时间字符串是否是昨天"""
     return TimeUtils.is_yesterday(create_time_str, dt)
 
-
 def is_yesterday_date(date_str: str) -> bool:
     """判断给定的日期字符串是否是昨天"""
     return TimeUtils.is_yesterday_date(date_str)
 
-
 def get_file_mtime(file_path: str, to_str: bool = True, tz_offset: int = 8) -> Union[str, datetime]:
     """获取文件的修改时间"""
     return TimeUtils.get_file_mtime(file_path, to_str, tz_offset)
 
-
 def convert_timestamp_to_str(timestamp_ms: Optional[int]) -> str:
     """将毫秒时间戳转换为字符串"""
     return TimeUtils.convert_timestamp_to_str(timestamp_ms)
 
-
 def convert_timestamp_to_date(timestamp_ms: Union[int, float]) -> str:
     """将毫秒时间戳转换为日期字符串"""
     return TimeUtils.convert_timestamp_to_date(timestamp_ms)
 
-
 def convert_datetime_to_date(datetime_str: str) -> str:
     """将格式为 'YYYY-MM-DD HH:MM:SS' 的时间字符串转换为 'YYYY-MM-DD' 格式的日期字符串"""
     return TimeUtils.convert_datetime_to_date(datetime_str)
 
-
 def get_current_year_range() -> Tuple[str, str]:
     """获取当前年份的开始和结束日期"""
     return TimeUtils.get_current_year_range()
 
-
 def get_start_timestamps(date_str: str) -> int:
     """获取指定日期的开始毫秒时间戳（00:00:00.000）"""
     return TimeUtils.get_start_timestamps(date_str)
 
-
 def get_end_timestamps(date_str: str) -> int:
     """获取指定日期的结束毫秒时间戳（23:59:59.999）"""
     return TimeUtils.get_end_timestamps(date_str)
 
-
 def format_date_cross_platform(date_str: str) -> str:
     """跨平台格式化日期"""
     return TimeUtils.format_date_cross_platform(date_str)
 
-
 def get_past_7_days_range(start_from: Optional[str] = None) -> Tuple[str, str]:
     """获取过去7天的日期范围（包括结束日，共7天）"""
     return TimeUtils.get_past_7_days_range(start_from)
 
-
 def get_past_7_days_range_format(start_from: Optional[str] = None, format_str: str = '%Y-%m-%d') -> Tuple[str, str]:
     """获取过去7天的日期范围（包括结束日，共7天），支持自定义格式"""
     return TimeUtils.get_past_7_days_range_format(start_from, format_str)
 
-
 def get_past_nth_day(n: int, start_from: Optional[str] = None) -> str:
     """获取过去第n天的日期"""
     return TimeUtils.get_past_nth_day(n, start_from)
 
-
 def get_past_n_days_list(n: int, start_from: Optional[str] = None) -> List[str]:
     """获取过去n天的日期列表，从最旧到最近的日期"""
     return TimeUtils.get_past_n_days_list(n, start_from)
 
-
 def get_past_7_days_list(start_from: Optional[str] = None) -> List[str]:
     """获取过去7天的日期列表（不包含 start_from 当天），共7天"""
     return TimeUtils.get_past_7_days_list(start_from)
 
-
 def date_range(start_date: str, end_date: str) -> List[str]:
     """生成两个日期之间的日期列表"""
     return TimeUtils.date_range(start_date, end_date)
 
-
 def get_dates_from_first_of_month_to_yesterday() -> List[str]:
     """获取从本月第一天到昨天的日期列表"""
     return TimeUtils.get_dates_from_first_of_month_to_yesterday()
 
-
 def get_last_month_range() -> Tuple[str, str]:
     """获取上个月的第一天和最后一天"""
     return TimeUtils.get_last_month_range()
 
-
 def get_last_month_range_time_str() -> Tuple[str, str]:
     """获取上个月第一天和最后一天的时间字符串"""
     return TimeUtils.get_last_month_range_time_str()
 
-
 def get_last_month_range_time() -> Tuple[int, int]:
     """获取上个月第一天和最后一天的毫秒级时间戳"""
     return TimeUtils.get_last_month_range_time()
 
-
 # 为了向后兼容，保留一些旧函数名
 def get_past_7_days_range_old() -> Tuple[str, str]:
     """获取过去7天的日期范围（旧版本）"""
@@ -824,7 +824,6 @@ def get_past_7_days_range_old() -> Tuple[str, str]:
     start_date = end_date - timedelta(days=6)  # 往前推6天为开始日期
     return start_date.strftime('%Y-%m-%d'), end_date.strftime('%Y-%m-%d')
 
-
 def get_past_7_days_list_old() -> List[str]:
     """获取过去7天的日期列表（旧版本）"""
     today = datetime.today()
@@ -833,7 +832,6 @@ def get_past_7_days_list_old() -> List[str]:
         for i in range(1, 8)
     ]
 
-
 if __name__ == "__main__":
     # 测试示例
     print(f"当前日期: {today_date()}")
